package com.lantone.qc.trans.changx;

import com.google.common.collect.Lists;
import com.lantone.qc.pub.model.doc.operation.OperationDiscussionDoc;
import com.lantone.qc.pub.model.doc.operation.OperationDoc;
import com.lantone.qc.pub.model.doc.operation.PreoperativeDiscussionDoc;
import com.lantone.qc.pub.model.keys.ModelStandardKeys;
import com.lantone.qc.pub.model.vo.MedrecVo;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import com.lantone.qc.trans.ModelDocTrans;
import com.lantone.qc.trans.comsis.ModelDocGenerate;
import com.lantone.qc.trans.comsis.Preproc;

import java.util.List;
import java.util.Map;

/**
 * @Description: 手术文档生成
 * @author: rengb
 * @time: 2020/3/20 17:11
 */
public class ChangxOperationDocTrans extends ModelDocTrans {

    @Override
    public List<OperationDoc> extract(MedrecVo medrecVo) {
        List<OperationDoc> retList = Lists.newArrayList();
        Map<String, Object> content = medrecVo.getContent();
        Map<String, List<String>> labelMap = (Map) content.get("label");
        List<String> operationDiscussionLabel = labelMap.get("术后首次病程及谈话记录");
        List<String> preoperativeDiscussionLabel = labelMap.get("术前讨论、术前小结");
        List<Map<String, String>> operations = (List) content.get("content");

        String operationDiscussionContent, preoperativeDiscussionContent;
        Map<String, String> operationDiscussionStructureMap, preoperativeDiscussionStructureMap;
        for (Map<String, String> operation : operations) {
            OperationDoc operationDoc = new OperationDoc();

            operationDiscussionContent = operation.get("术后首次病程及谈话记录");
            if (StringUtil.isNotBlank(operationDiscussionContent)) {
                operationDiscussionStructureMap =
                        Preproc.extract_doc_pub(
                                false,
                                ListUtil.isEmpty(operationDiscussionLabel) ? ModelStandardKeys.operationDiscussion : operationDiscussionLabel,
                                operationDiscussionContent
                        );

                operationDiscussionStructureMap.put("拟行术式", operationDiscussionStructureMap.get("拟施手术方式、名称及可能的变更"));
                operationDiscussionStructureMap.remove("拟施手术方式、名称及可能的变更");
                operationDiscussionStructureMap.put("手术指征", operationDiscussionStructureMap.get("手术指征与禁忌征"));
                operationDiscussionStructureMap.remove("手术指征与禁忌征");
                operationDiscussionStructureMap.put("可能意外和防范措施", operationDiscussionStructureMap.get("主要术中、术后风险及防范措施"));
                operationDiscussionStructureMap.remove("主要术中、术后风险及防范措施");
                operationDiscussionStructureMap.put("术前术后注意事项", operationDiscussionStructureMap.get("术中、术后注意事项（含护理事项）"));
                operationDiscussionStructureMap.remove("术中、术后注意事项（含护理事项）");
                operationDiscussionStructureMap.put("麻醉方式", operationDiscussionStructureMap.get("拟施麻醉方式"));
                operationDiscussionStructureMap.remove("拟施麻醉方式");
                operationDiscussionStructureMap.put("术前准备内容", operationDiscussionStructureMap.get("术前特殊准备"));
                operationDiscussionStructureMap.remove("术前特殊准备");

                OperationDiscussionDoc operationDiscussionDoc = ModelDocGenerate.operationDiscussionDocGen(operationDiscussionStructureMap);
                operationDiscussionDoc.setText(operationDiscussionContent);
                operationDoc.setOperationDiscussionDoc(operationDiscussionDoc);
            }

            preoperativeDiscussionContent = operation.get("术前讨论、术前小结");
            if (StringUtil.isNotBlank(preoperativeDiscussionContent)) {
                preoperativeDiscussionStructureMap =
                        Preproc.extract_doc_pub(
                                false,
                                ListUtil.isEmpty(preoperativeDiscussionLabel) ? ModelStandardKeys.preoperativeDiscussion : preoperativeDiscussionLabel,
                                preoperativeDiscussionContent
                        );
                PreoperativeDiscussionDoc preoperativeDiscussionDoc = ModelDocGenerate.preoperativeDiscussionDocGen(preoperativeDiscussionStructureMap);
                preoperativeDiscussionDoc.setText(preoperativeDiscussionContent);
                operationDoc.setPreoperativeDiscussionDoc(preoperativeDiscussionDoc);
            }

            retList.add(operationDoc);
        }
        return retList;
    }

}